Create A New Recipe
===================

In this section we will walk you through how to create a new Recipe.

..  warning::
    This section is not complete yet. Please refer to the
    `Recipe Schema </schemas/recipes.html>`_ section for now.

Getting Started
---------------


Folder Structure
----------------



Metadata Configuration
----------------------


Dependencies
------------


Flow
----


DAG Tasks
---------


Referencing Outputs to Inputs
-----------------------------



Artifact Path Context Resolution
--------------------------------


Working With Loops
------------------

